@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
 #    a copy of the License at
@@ -25,7 +23,7 @@ from taskflow.types import notifier
 from taskflow.utils import misc
 
 
-class Conductor(object, metaclass=abc.ABCMeta):
+class Conductor(metaclass=abc.ABCMeta):
     """Base for all conductor implementations.
 
     Conductors act as entities which extract jobs from a jobboard, assign
@@ -163,6 +161,30 @@ class Conductor(object, metaclass=abc.ABCMeta):
                                forever and/or until stopped).
         """
 
+    @abc.abstractmethod
+    def stop(self):
+        """Requests the conductor to stop dispatching.
+
+        This method can be used to request that a conductor stop its
+        consumption & dispatching loop.
+
+        The method returns immediately regardless of whether the conductor has
+        been stopped.
+        """
+
+    @abc.abstractmethod
+    def wait(self, timeout=None):
+        """Waits for the conductor to gracefully exit.
+
+        This method waits for the conductor to gracefully exit. An optional
+        timeout can be provided, which will cause the method to return
+        within the specified timeout. If the timeout is reached, the returned
+        value will be ``False``, otherwise it will be ``True``.
+
+        :param timeout: Maximum number of seconds that the :meth:`wait` method
+                        should block for.
+        """
+
     @abc.abstractmethod
     def _dispatch_job(self, job):
         """Dispatches a claimed job for work completion.
