@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2012 Yahoo! Inc. All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -22,16 +20,15 @@ import threading
 from automaton import runners
 from concurrent import futures
 import fasteners
+import functools
 import networkx as nx
 from oslo_utils import excutils
 from oslo_utils import strutils
 from oslo_utils import timeutils
-import six
 
 from taskflow.engines.action_engine import builder
 from taskflow.engines.action_engine import compiler
 from taskflow.engines.action_engine import executor
-from taskflow.engines.action_engine import process_executor
 from taskflow.engines.action_engine import runtime
 from taskflow.engines import base
 from taskflow import exceptions as exc
@@ -65,7 +62,7 @@ def _pre_check(check_compiled=True, check_storage_ensured=True,
     def decorator(meth):
         do_what = meth.__name__
 
-        @six.wraps(meth)
+        @functools.wraps(meth)
         def wrapper(self, *args, **kwargs):
             if check_compiled and not self._compiled:
                 raise exc.InvalidState("Can not %s an engine which"
@@ -166,7 +163,7 @@ class ActionEngine(base.Engine):
     """
 
     def __init__(self, flow, flow_detail, backend, options):
-        super(ActionEngine, self).__init__(flow, flow_detail, backend, options)
+        super().__init__(flow, flow_detail, backend, options)
         self._runtime = None
         self._compiled = False
         self._compilation = None
@@ -335,8 +332,8 @@ class ActionEngine(base.Engine):
                             e_failures = self.storage.get_execute_failures()
                             r_failures = self.storage.get_revert_failures()
                             er_failures = itertools.chain(
-                                six.itervalues(e_failures),
-                                six.itervalues(r_failures))
+                                e_failures.values(),
+                                r_failures.values())
                             failure.Failure.reraise_if_any(er_failures)
             finally:
                 if w is not None:
@@ -475,8 +472,7 @@ class SerialActionEngine(ActionEngine):
     """Engine that runs tasks in serial manner."""
 
     def __init__(self, flow, flow_detail, backend, options):
-        super(SerialActionEngine, self).__init__(flow, flow_detail,
-                                                 backend, options)
+        super().__init__(flow, flow_detail, backend, options)
         self._task_executor = executor.SerialTaskExecutor()
 
 
@@ -544,7 +540,6 @@ String (case insensitive)    Executor used
       polling while a higher number will involve less polling but a slower time
       for an engine to notice a task has completed.
 
-    .. |pe|  replace:: process_executor
     .. |cfp| replace:: concurrent.futures.process
     .. |cft| replace:: concurrent.futures.thread
     .. |cf| replace:: concurrent.futures
@@ -559,8 +554,6 @@ String (case insensitive)    Executor used
     _executor_cls_matchers = [
         _ExecutorTypeMatch((futures.ThreadPoolExecutor,),
                            executor.ParallelThreadTaskExecutor),
-        _ExecutorTypeMatch((futures.ProcessPoolExecutor,),
-                           process_executor.ParallelProcessTaskExecutor),
         _ExecutorTypeMatch((futures.Executor,),
                            executor.ParallelThreadTaskExecutor),
     ]
@@ -569,8 +562,6 @@ String (case insensitive)    Executor used
     # 'executor' option (a mixed case equivalent is allowed since the match
     # will be lower-cased before checking).
     _executor_str_matchers = [
-        _ExecutorTextMatch(frozenset(['processes', 'process']),
-                           process_executor.ParallelProcessTaskExecutor),
         _ExecutorTextMatch(frozenset(['thread', 'threads', 'threaded']),
                            executor.ParallelThreadTaskExecutor),
         _ExecutorTextMatch(frozenset(['greenthread', 'greenthreads',
@@ -582,8 +573,7 @@ String (case insensitive)    Executor used
     _default_executor_cls = executor.ParallelThreadTaskExecutor
 
     def __init__(self, flow, flow_detail, backend, options):
-        super(ParallelActionEngine, self).__init__(flow, flow_detail,
-                                                   backend, options)
+        super().__init__(flow, flow_detail, backend, options)
         # This ensures that any provided executor will be validated before
         # we get to far in the compilation/execution pipeline...
         self._task_executor = self._fetch_task_executor(self._options)
@@ -594,7 +584,7 @@ String (case insensitive)    Executor used
         executor_cls = cls._default_executor_cls
         # Match the desired executor to a class that will work with it...
         desired_executor = options.get('executor')
-        if isinstance(desired_executor, six.string_types):
+        if isinstance(desired_executor, str):
             matched_executor_cls = None
             for m in cls._executor_str_matchers:
                 if m.matches(desired_executor):
