@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2014 Yahoo! Inc. All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -18,7 +16,6 @@ import functools
 import threading
 
 from oslo_utils import timeutils
-import six
 
 from taskflow.engines.action_engine import executor
 from taskflow.engines.worker_based import dispatcher
@@ -141,7 +138,7 @@ class WorkerTaskExecutor(executor.TaskExecutor):
         if not self._ongoing_requests:
             return
         with self._ongoing_requests_lock:
-            ongoing_requests_uuids = set(six.iterkeys(self._ongoing_requests))
+            ongoing_requests_uuids = set(self._ongoing_requests.keys())
         waiting_requests = {}
         expired_requests = {}
         for request_uuid in ongoing_requests_uuids:
