@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2014 Yahoo! Inc. All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -15,14 +13,13 @@
 #    under the License.
 
 import collections
+import threading
 
 import kombu
 from kombu import exceptions as kombu_exceptions
-import six
 
 from taskflow.engines.worker_based import dispatcher
 from taskflow import logging
-from taskflow.utils import threading_utils
 
 LOG = logging.getLogger(__name__)
 
@@ -41,7 +38,7 @@ _TransportDetails = collections.namedtuple('_TransportDetails',
                                             'driver_name', 'driver_version'])
 
 
-class Proxy(object):
+class Proxy:
     """A proxy processes messages from/to the named exchange.
 
     For **internal** usage only (not for public consumption).
@@ -75,7 +72,7 @@ class Proxy(object):
         self._topic = topic
         self._exchange_name = exchange
         self._on_wait = on_wait
-        self._running = threading_utils.Event()
+        self._running = threading.Event()
         self._dispatcher = dispatcher.TypeDispatcher(
             # NOTE(skudriashev): Process all incoming messages only if proxy is
             # running, otherwise requeue them.
@@ -85,7 +82,7 @@ class Proxy(object):
         ensure_options = self.DEFAULT_RETRY_OPTIONS.copy()
         if retry_options is not None:
             # Override the defaults with any user provided values...
-            for k in set(six.iterkeys(ensure_options)):
+            for k in set(ensure_options.keys()):
                 if k in retry_options:
                     # Ensure that the right type is passed in...
                     val = retry_options[k]
@@ -146,7 +143,7 @@ class Proxy(object):
 
     def _make_queue(self, routing_key, exchange, channel=None):
         """Make a named queue for the given exchange."""
-        queue_name = "%s_%s" % (self._exchange_name, routing_key)
+        queue_name = "{}_{}".format(self._exchange_name, routing_key)
         return kombu.Queue(name=queue_name,
                            routing_key=routing_key, durable=False,
                            exchange=exchange, auto_delete=True,
@@ -154,7 +151,7 @@ class Proxy(object):
 
     def publish(self, msg, routing_key, reply_to=None, correlation_id=None):
         """Publish message to the named exchange with given routing key."""
-        if isinstance(routing_key, six.string_types):
+        if isinstance(routing_key, str):
             routing_keys = [routing_key]
         else:
             routing_keys = routing_key
@@ -162,9 +159,9 @@ class Proxy(object):
         # Filter out any empty keys...
         routing_keys = [r_k for r_k in routing_keys if r_k]
         if not routing_keys:
-            LOG.warn("No routing key/s specified; unable to send '%s'"
-                     " to any target queue on exchange '%s'", msg,
-                     self._exchange_name)
+            LOG.warning("No routing key/s specified; unable to send '%s'"
+                        " to any target queue on exchange '%s'", msg,
+                        self._exchange_name)
             return
 
         def _publish(producer, routing_key):
