@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2012-2013 Yahoo! Inc. All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -31,9 +29,8 @@ sys.path.insert(0, self_dir)
 
 from taskflow import engines
 from taskflow.patterns import linear_flow as lf
-from taskflow.persistence import logbook
+from taskflow.persistence import models
 from taskflow import task
-from taskflow.utils import persistence_utils as p_utils
 
 import example_utils as eu  # noqa
 
@@ -59,7 +56,7 @@ class HiTask(task.Task):
 
 class ByeTask(task.Task):
     def __init__(self, blowup):
-        super(ByeTask, self).__init__()
+        super().__init__()
         self._blowup = blowup
 
     def execute(self):
@@ -68,15 +65,15 @@ class ByeTask(task.Task):
         print("Bye!")
 
 
-# This generates your flow structure (at this stage nothing is ran).
+# This generates your flow structure (at this stage nothing is run).
 def make_flow(blowup=False):
     flow = lf.Flow("hello-world")
     flow.add(HiTask(), ByeTask(blowup))
     return flow
 
 
-# Persist the flow and task state here, if the file/dir exists already blowup
-# if not don't blowup, this allows a user to see both the modes and to see
+# Persist the flow and task state here, if the file/dir exists already blow up
+# if not don't blow up, this allows a user to see both the modes and to see
 # what is stored in each case.
 if eu.SQLALCHEMY_AVAILABLE:
     persist_path = os.path.join(tempfile.gettempdir(), "persisting.db")
@@ -91,10 +88,10 @@ else:
     blowup = True
 
 with eu.get_backend(backend_uri) as backend:
-    # Make a flow that will blowup if the file doesn't exist previously, if it
-    # did exist, assume we won't blowup (and therefore this shows the undo
+    # Make a flow that will blow up if the file didn't exist previously, if it
+    # did exist, assume we won't blow up (and therefore this shows the undo
     # and redo that a flow will go through).
-    book = logbook.LogBook("my-test")
+    book = models.LogBook("my-test")
     flow = make_flow(blowup=blowup)
     eu.print_wrapped("Running")
     try:
@@ -110,4 +107,4 @@ with eu.get_backend(backend_uri) as backend:
         traceback.print_exc(file=sys.stdout)
 
     eu.print_wrapped("Book contents")
-    print(p_utils.pformat(book))
+    print(book.pformat())
