@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2013 Yahoo! Inc. All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -46,7 +44,7 @@ class LoggingListener(base.DumpingListener):
                  retry_listen_for=base.DEFAULT_LISTEN_FOR,
                  log=None,
                  level=logging.DEBUG):
-        super(LoggingListener, self).__init__(
+        super().__init__(
             engine, task_listen_for=task_listen_for,
             flow_listen_for=flow_listen_for, retry_listen_for=retry_listen_for)
         self._logger = misc.pick_first_not_none(log, self._LOGGER, LOG)
@@ -110,8 +108,10 @@ class DynamicLoggingListener(base.Listener):
                  retry_listen_for=base.DEFAULT_LISTEN_FOR,
                  log=None, failure_level=logging.WARNING,
                  level=logging.DEBUG, hide_inputs_outputs_of=(),
-                 fail_formatter=None):
-        super(DynamicLoggingListener, self).__init__(
+                 fail_formatter=None,
+                 mask_inputs_keys=(),
+                 mask_outputs_keys=()):
+        super().__init__(
             engine, task_listen_for=task_listen_for,
             flow_listen_for=flow_listen_for, retry_listen_for=retry_listen_for)
         self._failure_level = failure_level
@@ -127,11 +127,15 @@ class DynamicLoggingListener(base.Listener):
             states.REVERTED: self._failure_level,
         }
         self._hide_inputs_outputs_of = frozenset(hide_inputs_outputs_of)
+        self._mask_inputs_keys = frozenset(mask_inputs_keys)
+        self._mask_outputs_keys = frozenset(mask_outputs_keys)
         self._logger = misc.pick_first_not_none(log, self._LOGGER, LOG)
         if fail_formatter is None:
             self._fail_formatter = formatters.FailureFormatter(
                 self._engine,
-                hide_inputs_outputs_of=self._hide_inputs_outputs_of)
+                hide_inputs_outputs_of=self._hide_inputs_outputs_of,
+                mask_inputs_keys=self._mask_inputs_keys,
+                mask_outputs_keys=self._mask_outputs_keys)
         else:
             self._fail_formatter = fail_formatter
 
