@@ -18,25 +18,16 @@
 
 import os
 
-from alembic import config as a_config
-from alembic import environment as a_env
-from alembic import script as a_script
+from alembic import command
+from alembic import config
 
 
-def _alembic_config():
+def _make_alembic_config():
     path = os.path.join(os.path.dirname(__file__), 'alembic', 'alembic.ini')
-    return a_config.Config(path)
+    return config.Config(path)
 
 
 def db_sync(connection, revision='head'):
-    script = a_script.ScriptDirectory.from_config(_alembic_config())
-
-    def upgrade(rev, context):
-        return script._upgrade_revs(revision, rev)
-
-    config = _alembic_config()
-    with a_env.EnvironmentContext(config, script, fn=upgrade, as_sql=False,
-                                  starting_rev=None, destination_rev=revision,
-                                  tag=None) as context:
-        context.configure(connection=connection)
-        context.run_migrations()
+    cfg = _make_alembic_config()
+    cfg.attributes['connection'] = connection
+    command.upgrade(cfg, revision)
