@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 #    Copyright (C) 2014 AT&T Labs All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -56,7 +54,7 @@ class ZkPersistenceTest(test.TestCase, base.PersistenceTestMixin):
         return self.backend.get_connection()
 
     def setUp(self):
-        super(ZkPersistenceTest, self).setUp()
+        super().setUp()
         conf = test_utils.ZK_TEST_CONFIG.copy()
         # Create a unique path just for this test (so that we don't overwrite
         # what other tests are doing).
@@ -84,7 +82,7 @@ class ZakePersistenceTest(test.TestCase, base.PersistenceTestMixin):
         return self._backend.get_connection()
 
     def setUp(self):
-        super(ZakePersistenceTest, self).setUp()
+        super().setUp()
         conf = {
             "path": "/taskflow",
         }
