@@ -34,12 +34,13 @@ from taskflow import states
 
 # This is just needed to get at the machine object (we will not
 # actually be running it...).
-class DummyRuntime(object):
+class DummyRuntime:
     def __init__(self):
         self.analyzer = mock.MagicMock()
         self.completer = mock.MagicMock()
         self.scheduler = mock.MagicMock()
         self.storage = mock.MagicMock()
+        self.selector = mock.MagicMock()
 
 
 def make_machine(start_state, transitions, event_name_cb):
@@ -129,7 +130,7 @@ def main():
     elif options.engines:
         source_type = "Engines"
         b = builder.MachineBuilder(DummyRuntime(), mock.MagicMock())
-        source, memory = b.build()
+        source, memory = b.build({})
         internal_states.extend(builder.META_STATES)
         ordering = 'out'
     elif options.wbe_requests:
@@ -184,7 +185,7 @@ def main():
     print(g.to_string().strip())
 
     g.write(options.filename, format=options.format)
-    print("Created %s at '%s'" % (options.format, options.filename))
+    print("Created {} at '{}'".format(options.format, options.filename))
 
     # To make the svg more pretty use the following:
     # $ xsltproc ../diagram-tools/notugly.xsl ./states.svg > pretty-states.svg
